Documentation
¶
Overview ¶
Package configurepackage implements the ConfigurePackage plugin.
Package configurepackage implements the ConfigurePackage plugin. configurepackage_deps contains platform dependencies that should be able to be stubbed out in tests
Package configurepackage implements the ConfigurePackage plugin.
Index ¶
Constants ¶
const ( // InstallAction represents the json command to install package InstallAction = "Install" // UninstallAction represents the json command to uninstall package UninstallAction = "Uninstall" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ConfigurePackagePluginInput ¶
type ConfigurePackagePluginInput struct {
contracts.PluginInput
Name string `json:"name"`
Version string `json:"version"`
Action string `json:"action"`
Source string `json:"source"`
Repository string `json:"repository"`
}
ConfigurePackagePluginInput represents one set of commands executed by the ConfigurePackage plugin.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
facade
This interface is created manally based on the ssmiface.SSMAPI.
|
This interface is created manally based on the ssmiface.SSMAPI. |
|
Package installer implements interfaces for installing and uninstalling packages
|
Package installer implements interfaces for installing and uninstalling packages |
|
mock
Package installer_mock implements the mock for the installer package
|
Package installer_mock implements the mock for the installer package |
|
Package localpackages implements the local storage for packages managed by the ConfigurePackage plugin.
|
Package localpackages implements the local storage for packages managed by the ConfigurePackage plugin. |
|
mock
Package repository_mock implements the mock for Repository.
|
Package repository_mock implements the mock for Repository. |
|
Package ssminstaller implements the installer for ssm packages that use documents or scripts to install and uninstall.
|
Package ssminstaller implements the installer for ssm packages that use documents or scripts to install and uninstall. |
Click to show internal directories.
Click to hide internal directories.